package de.hazewood.rylius.mlgj1;

import org.newdawn.slick.Image;
import org.newdawn.slick.Music;
import org.newdawn.slick.Sound;
import org.newdawn.slick.geom.Vector2f;

import java.util.Random;
import java.util.logging.Level;
import java.util.logging.Logger;

public class Game {

    public static final String BASEPATH = "de/hazewood/rylius/mlgj1/";
    public static final Random RANDOM = new Random();
    private static Music music;
    private static final Logger LOGGER = Logger.getLogger(Game.class.getName());

    public static Image image(String file) {
        String path = BASEPATH + "graphics/";
        try {
            return new Image(path + file + ".png");
        } catch (Exception ex) {
            LOGGER.log(Level.WARNING, "Failed to open image '" + file + "'");
            if (!file.equals("missing")) {
                return image("missing");
            }
        }
        return null;
    }

    public static Sound sound(String file) {
        String path = BASEPATH + "sounds/";
        try {
            return new Sound(path + file + ".ogg");
        } catch (Exception ex) {
            LOGGER.log(Level.WARNING, "Failed to open sound '" + file + "'");
        }
        return null;
    }

    public static Music music(String file) {
        String path = BASEPATH + "music/";
        try {
            return new Music(path + file + ".ogg");
        } catch (Exception ex) {
            LOGGER.log(Level.WARNING, "Failed to open music '" + file + "'");
            if (!file.matches("missing")) {
                return music("missing");
            }
        }
        return null;
    }

    public static boolean parseBool(String str) {
        if (str.equalsIgnoreCase("true")) {
            return true;
        }
        return false;
    }

    public static int parseInt(String str) {
        if (str.isEmpty()) {
            return 0;
        } else {
            return Integer.parseInt(str);
        }
    }

    public static Vector2f parseVector(String str) {
        String[] parts = str.split("\\|");
        return new Vector2f(Game.parseFloat(parts[0]), Game.parseFloat(parts[1]));
    }

    public static float parseFloat(String str) {
        if (str.isEmpty()) {
            return 0f;
        } else {
            try {
                return Float.parseFloat(str);
            } catch (NumberFormatException ex) {
                LOGGER.log(Level.WARNING, "Wrong number format for '" + str + "' (expected float)");
                return 0;
            }
        }
    }

    public static void setMusic(Music music) {
        Game.music = music;
    }

    public static Music getMusic() {
        return music;
    }
}
