package de.hazewood.rylius.mlgj1;

import de.hazewood.rylius.mlgj1.levels.Level;
import de.hazewood.rylius.mlgj1.levels.Maze;
import org.lwjgl.LWJGLUtil;
import org.newdawn.slick.*;

import java.io.File;
import java.util.HashMap;
import java.util.Map;
import java.util.logging.Logger;

public final class MLGJ1 extends BasicGame {

    private final Map<String, Integer> state;
    private Level level;

    public static void main(String[] args) {
        System.setProperty("org.lwjgl.librarypath", new File(new File(System.getProperty("user.dir"), "native"), LWJGLUtil.getPlatformName()).getAbsolutePath());
        System.setProperty("net.java.games.input.librarypath", System.getProperty("org.lwjgl.librarypath"));
        AppGameContainer app = null;
        try {
            app = new AppGameContainer(new MLGJ1());
            app.setDisplayMode(800, 600, false);
            app.setTargetFrameRate(60);
            app.setShowFPS(false);
            app.start();
        } catch (SlickException ex) {
            Logger.getLogger(MLGJ1.class.getName()).log(java.util.logging.Level.SEVERE, null, ex);
            System.exit(1);
        }
    }

    public MLGJ1() {
        super("My Little Game Jam #1: King of Chaos");

        state = new HashMap<String, Integer>();
        reset();
    }

    @Override
    public void init(GameContainer container) throws SlickException {
        loadLevel(new Maze(this));
        //        loadLevel(new MazeApplejack(this));
        //        loadLevel(new MazeRarity(this));
    }

    public void loadLevel(Level level) {
        this.level = level;
    }

    @Override
    public void update(GameContainer gc, int delta) throws SlickException {
        level.update(gc, delta);
    }

    @Override
    public void render(GameContainer gc, Graphics g) throws SlickException {
        level.draw(gc, g);
    }

    public Map<String, Integer> getState() {
        return state;
    }

    public void reset() {
        state.clear();
        state.put("maze_aj", -1);
//        state.put("maze_pp", -1);
        state.put("maze_rd", -1);
        state.put("maze_rarity", -1);
//        state.put("maze_fs", -1);
    }
}
