package de.hazewood.rylius.mlgj1.particles;

import de.hazewood.rylius.mlgj1.Element;
import org.newdawn.slick.GameContainer;
import org.newdawn.slick.Graphics;
import org.newdawn.slick.Image;
import org.newdawn.slick.geom.Vector2f;

import java.util.LinkedList;
import java.util.List;
import java.util.Random;

public class Emitter extends Element {

    private Image particle;
    private int amount;
    private int duration;
    private List<Particle> particles;
    private Vector2f velocity;
    private Vector2f offset;
    private Random random;
    private boolean running;
    private int ground;

    public Emitter(Image particle, int amount, int duration, Vector2f offset, Vector2f velocity, Vector2f gravity) {
        super(null);

        particles = new LinkedList<Particle>();

        this.particle = particle;
        this.amount = amount;
        this.duration = duration;
        this.offset = offset;
        this.velocity = velocity;
        this.gravity = gravity;

        this.random = new Random();

        running = true;
    }

    public void stop() {
        running = false;
    }

    @Override
    public void update(GameContainer gc, int delta) {
        super.update(gc, delta);

        if (running) {
            if (duration >= 0 && particles.size() < amount) {
                addParticle();
            } else if (duration == -1) {
                while (particles.size() < amount) {
                    addParticle();
                }
            }
        }

        List<Particle> remove = new LinkedList<Particle>();
        for (Particle p : particles) {
            p.update(gc, delta);
            if (p.isRemoveable()) {
                remove.add(p);
            }
        }
        particles.removeAll(remove);
    }

    private void addParticle() {
        Vector2f origin = origin();
        Particle p = new Particle(particle);

        float x = random.nextInt((int) offset.getX() * 2) - offset.getX();
        float y = random.nextInt((int) offset.getY() * 2) - offset.getY();
        p.getPos().set(origin.getX() + x, origin.getY() + y);
        p.getVel().set(velocity);
        p.setGround(ground);
        p.setGravity(gravity);

        particles.add(p);
    }

    @Override
    public void draw(GameContainer gc, Graphics g) {
        for (Particle p : particles) {
            p.draw(gc, g);
        }

        super.draw(gc, g);
    }

    @Override
    public boolean isRemoveable() {
        return !running && particles.isEmpty();
    }

    public void setGround(int ground) {
        this.ground = ground;
    }

    @Override
    public boolean combine(Element other) {
        return false;
    }
}
